/*
 * oled.c
 *
 *  Created on: Nov 13, 2024
 *      Author: wuxiaoao
 */
#include "main.h"
#include "oled.h"
#include "oledfont.h"
#include "i2c.h"

/*******************************修改内容*****************************/

//初始化命令
uint8_t CMD_Data[]={0xAE,0x00,0x10,0x40,0xB0,0x81,0xFF,0xA1,0xA6,0xA8,
										0x3F,0xC8,0xD3,0x00,0xD5,0x80,0xD8,0x05,0xD9,0xF1,
										0xDA, 0x12, 0xD8, 0x30, 0x8D,0x14, 0xAF};

//向设备写控制命
void OLED_WR_CMD(uint8_t cmd)
{
	WriteNbyte(0x00,&cmd,1);
}
//向设备写数据
void OLED_WR_DATA(uint8_t data1)
{
	WriteNbyte(0x40,&data1,1);
}


//初始化oled屏幕
void OLED_Init(void)
{
	uint8_t i = 0;
	delay_ms(100);
	for(i=0; i<27; i++)
		OLED_WR_CMD(CMD_Data[i]);
	OLED_Clear();
}
//清屏size12 size16要清两行，其他函数有类似情况
void OLED_Clear()
{
	uint8_t i,n;
	for(i=0;i<8;i++)
	{
		OLED_WR_CMD(0xb0+i);
		OLED_WR_CMD (0x00);
		OLED_WR_CMD (0x10);
		for(n=0;n<128;n++)
			OLED_WR_DATA(0);
	}
}
//清行
void OLED_Clearrow(uint8_t i)
{
	uint8_t n;
	OLED_WR_CMD(0xb0+i);
		OLED_WR_CMD (0x00);
		OLED_WR_CMD (0x10);
		for(n=0;n<128;n++)
			OLED_WR_DATA(0);
}
//开启OLED显示
void OLED_Display_On(void)
{
	OLED_WR_CMD(0X8D);  //SET DCDC命令
	OLED_WR_CMD(0X14);  //DCDC ON
	OLED_WR_CMD(0XAF);  //DISPLAY ON
}
//关闭OLED显示
void OLED_Display_Off(void)
{
	OLED_WR_CMD(0X8D);  //SET DCDC命令
	OLED_WR_CMD(0X10);  //DCDC OFF
	OLED_WR_CMD(0XAE);  //DISPLAY OFF
}
void OLED_Set_Pos(uint8_t x, uint8_t y)
{
	OLED_WR_CMD(0xb0+y);
	OLED_WR_CMD(((x&0xf0)>>4)|0x10);
	OLED_WR_CMD(x&0x0f);
}

void OLED_On(void)
{
	uint8_t i,n;
	for(i=0;i<8;i++)
	{
		OLED_WR_CMD(0xb0+i);    //设置页地址（0~7）
		OLED_WR_CMD(0x00);      //设置显示位置—列低地址
		OLED_WR_CMD(0x10);      //设置显示位置—列高地址
		for(n=0;n<128;n++)
			OLED_WR_DATA(1);
	} //更新显示
}
unsigned int oled_pow(uint8_t m,uint8_t n)
{
	unsigned int result=1;
	while(n--)result*=m;
	return result;
}

//在指定位置显示一个字符,包括部分字符
//x:0~127
//y:0~63
//mode:0,反白显示;1,正常显示
//size:选择字体 16/12
void OLED_ShowChar(uint8_t x,uint8_t y,uint8_t chr,uint8_t Char_Size)
{
	unsigned char c=0,i=0;
		c=chr-' ';//得到偏移后的值ws
		if(x>128-1){x=0;y=y+2;}
		if(Char_Size ==48)
		{
//			OLED_Set_Pos(x,y);
//			for(i=0;i<24;i++)
//			OLED_WR_DATA(F24x48[c*144+i]);
//			OLED_Set_Pos(x,y+1);
//			for(i=0;i<24;i++)
//			OLED_WR_DATA(F24x48[c*144+i+24]);
//			OLED_Set_Pos(x,y+2);
//			for(i=0;i<24;i++)
//			OLED_WR_DATA(F24x48[c*144+i+48]);
//			OLED_Set_Pos(x,y+3);
//			for(i=0;i<24;i++)
//			OLED_WR_DATA(F24x48[c*144+i+72]);
//			OLED_Set_Pos(x,y+4);
//			for(i=0;i<24;i++)
//			OLED_WR_DATA(F24x48[c*144+i+96]);
//			OLED_Set_Pos(x,y+5);
//			for(i=0;i<24;i++)
//			OLED_WR_DATA(F24x48[c*144+i+120]);
			
		}
		else if(Char_Size==32)
		{
			OLED_Set_Pos(x,y);
			for(i=0;i<16;i++)
			OLED_WR_DATA(F16x32[c*64+i]);
			OLED_Set_Pos(x,y+1);
			for(i=0;i<16;i++)
			OLED_WR_DATA(F16x32[c*64+i+16]);
			OLED_Set_Pos(x,y+2);
			for(i=0;i<16;i++)
			OLED_WR_DATA(F16x32[c*64+i+32]);
			OLED_Set_Pos(x,y+3);
			for(i=0;i<16;i++)
			OLED_WR_DATA(F16x32[c*64+i+48]);
		}
		else if(Char_Size==16)
		{
			OLED_Set_Pos(x,y);
			for(i=0;i<8;i++)
			OLED_WR_DATA(F8x16[c*16+i]);
			OLED_Set_Pos(x,y+1);
			for(i=0;i<8;i++)
			OLED_WR_DATA(F8x16[c*16+i+8]);
		}
}

//显示一个字符号串
void OLED_ShowString(uint8_t x,uint8_t y,char *chr,uint8_t Char_Size)
{
	unsigned char j=0;
	while (chr[j]!='\0')
	{	
		OLED_ShowChar(x,y,chr[j],Char_Size);
		if(Char_Size==48)
			x+=24;
		else if(Char_Size==32)
			x+=16;
		else
			x+=8;
		if(x>120){x=0;y+=2;}
			j++;
	}
	
}
